import { Injectable } from '@nestjs/common';
import { CreateDirectorDto } from './dto/create-director.dto';
import { UpdateDirectorDto } from './dto/update-director.dto';
import { PrismaService } from '../../prisma.service';

@Injectable()
export class DirectorsService {
  constructor(private prisma: PrismaService) {}

  async create(createDirectorDto: CreateDirectorDto) {
    return await this.prisma.director.create({
      data: createDirectorDto,
    });
  }

  async findAll() {
    return await this.prisma.director.findMany();
  }

  async findOne(id: string) {
    return await this.prisma.director.findUnique({
      where: {
        id,
      },
    });
  }

  async update(id: string, updateDirectorDto: UpdateDirectorDto) {
    return await this.prisma.director.update({
      where: {
        id,
      },
      data: {
        ...updateDirectorDto,
      },
    });
  }

  async remove(id: string) {
    const directorMovie = await this.prisma.movie.findFirst({
      where: {
        directorId: id,
        deletedAt: null,
      },
      select: {
        id: true
      }
    });

    if (directorMovie === undefined) {
      return await this.prisma.director.update({
        where: {
          id,
        },
        data: {
          deletedAt: new Date(),
        },
      });
    }

    return await this.findOne(id);
  }
}
