import { Injectable } from '@nestjs/common';
import { CreateMovieDto } from './dto/create-movie.dto';
import { UpdateMovieDto } from './dto/update-movie.dto';
import { PrismaService } from '../../prisma.service';

@Injectable()
export class MoviesService {
  constructor(private prisma: PrismaService) {}

  async create(createMovieDto: CreateMovieDto) {
    return await this.prisma.movie.create({
      data: createMovieDto,
    });
  }

  async findAll() {
    return await this.prisma.movie.findMany();
  }

  async findOne(id: string) {
    return await this.prisma.movie.findUnique({
      where: {
        id,
      },
    });
  }

  async addCategory(movieId: string, categoryName: string) {
    await this.prisma.category.update({
      data: {
        movies: {
          connect: {
            id: movieId,
          },
        },
      },
      where: {
        name: categoryName,
      },
    });

    return await this.prisma.movie.update({
      data: {
        categories: {
          connect: {
            name: categoryName,
          },
        },
      },
      where: {
        id: movieId,
      },
      include: {
        categories: true,
      },
    });
  }

  async update(id: string, updateMovieDto: UpdateMovieDto) {
    return await this.prisma.movie.update({
      where: {
        id,
      },
      data: {
        ...updateMovieDto,
      },
    });
  }

  async remove(id: string) {
    return await this.prisma.movie.update({
      where: {
        id,
      },
      data: {
        deletedAt: new Date(),
      }
    });
  }
}
